@@ -17,14 +17,11 @@ class EnterpriseReportingModelManager(models.Manager):
     Custom ModelManager for every model that wants to use `enterprise_reporting` database.
     """
 
-    def get_queryset(self):
+    def db_manager(self, using=None, hints=None):  # pylint: disable=unused-argument
         """
         Override to use the `enterprise_reporting` database instead of default.
         """
-        qs = super().get_queryset()
-        qs = qs.using(settings.ENTERPRISE_REPORTING_DB_ALIAS)
-
-        return qs
+        return super().db_manager(using=settings.ENTERPRISE_REPORTING_DB_ALIAS, hints=hints)
 
 
 class EnterpriseLearner(models.Model):
@@ -39,6 +36,7 @@ class EnterpriseLearner(models.Model):
         db_table = 'enterprise_learner'
         verbose_name = _("Enterprise Learner")
         verbose_name_plural = _("Enterprise Learner")
+        ordering = ['-user_email']
 
     enterprise_user_id = models.PositiveIntegerField(primary_key=True)
     enterprise_customer_uuid = models.UUIDField(db_index=True, null=False)
